@@ -51,15 +51,15 @@ class BaseDate:
     def __add__(self, other):
         try:
             return JulianDay(self.jd + other)._to_x(self)
-        except AttributeError:
+        except TypeError:
             raise TypeError('You can only add a number to a date.')
 
     def __sub__(self, other):
-        if isinstance(other, Number):
-            return JulianDay(self.jd - other)._to_x(self)
         try:
+            if isinstance(other, Number):
+                return JulianDay(self.jd - other)._to_x(self)
             return abs(self.jd - other.jd)
-        except AttributeError:
+        except (AttributeError, TypeError):
             raise TypeError("""You can only subtract a number or another date
                               that has a "jd" attribute from a date""")
 
@@ -122,6 +122,20 @@ class BaseDate:
         """
         return self + (7 - self.weekday())
 
+    def isoweekday(self):
+        """Return the day of the week corresponding to the iso standard.
+
+        Returns
+        -------
+        int
+          An integer representing the day of the week where Monday
+          is 1 and and Sunday is 7.
+        """
+        weekday = self.weekday() 
+        if weekday == 1:
+            return 7
+        return weekday - 1
+
 
 class CalendarDateMixin:
     """CalendarDateMixin is a mixin for Hebrew and Gregorian dates.
@@ -176,7 +190,7 @@ class CalendarDateMixin:
           through Saturday as 7.
         """
         return int(self.jd+.5+1) % 7 + 1
-
+    
     def tuple(self):
         """Return date as tuple.
 
