@@ -5,47 +5,8 @@ from functools import lru_cache
 from pyluach.dates import HebrewDate
 
 
-def _adjust_postponed(date):
-    """Return actual date of fast day.
-
-    For usual date of a fast day returns fast day adjusted for any
-    postponements.
-    """
-    if date.weekday() == 7:
-        if date.month in [12, 13]:
-            date -= 2
-        else:
-            date += 1
-    return date
-
-
-@lru_cache(maxsize=50)
-def _fast_day_table(year):
-    table = dict()
-    workingdate = _adjust_postponed(HebrewDate(year, 7, 3))
-    table[workingdate] = 'Tzom Gedalia'
-
-    workingdate = _adjust_postponed(HebrewDate(year, 10, 10))
-    table[workingdate] = '10 of Teves'
-
-    month = 13 if Year(year).leap else 12
-    workingdate = _adjust_postponed(HebrewDate(year, month, 13))
-    table[workingdate] = 'Taanis Esther'
-
-    workingdate = _adjust_postponed(HebrewDate(year, 4, 17))
-    table[workingdate] = '17 of Tamuz'
-
-    workingdate = _adjust_postponed(HebrewDate(year, 5, 9))
-    table[workingdate] = '9 of Av'
-
-    return table
-
-
-def holiday(date, israel=False):
-    """Return Jewish holiday of given date.
-
-    The holidays include the major and minor religious Jewish
-    holidays including fast days.
+def fast_day(date):
+    """Return name of fast day or None.
 
     Parameters
     ----------
@@ -53,23 +14,61 @@ def holiday(date, israel=False):
       Any date that implements a ``to_heb()`` method which returns a
       ``HebrewDate`` can be used.
 
-    israel : boolian, optional
-      ``True`` if you want the holidays according to the israel
-      schedule. Defaults to ``False``.
-
     Returns
     -------
     str or ``None``
-      The name of the holiday or ``None`` if the given date is not
-      a Jewish holiday.
+      The name of the fast day or ``None`` if the given date is not
+      a fast day.
+    """
+    date = date.to_heb()
+    year = date.year
+    month = date.month
+    day = date.day
+    weekday = date.weekday()
+    adar = 13 if Year(year).leap else 12
+
+    if month == 7:
+        if (weekday == 1 and day == 4) or (weekday != 7 and day == 3):
+            return 'Tzom Gedalia'
+    elif month == 10 and day == 10:
+        return '10 of Teves'
+    elif month == adar:
+        if (weekday == 5 and day == 11) or weekday != 7 and day == 13:
+            return 'Taanis Esther'
+    elif month == 4:
+        if (weekday == 1 and day == 18) or (weekday != 7 and day == 17):
+            return '17 of Tamuz'
+    elif month == 5:
+        if (weekday == 1 and day == 10) or (weekday != 7 and day == 9):
+            return '9 of Av'
+
+
+def festival(date, israel=False):
+    """Return Jewish festival of given day.
+
+    This method will return all major and minor religous
+    Jewish holidays not including fast days.
+
+    Parameters
+    ----------
+    date : ``HebrewDate``, ``GregorianDate``, or ``JulianDay``
+      Any date that implements a ``to_heb()`` method which returns a
+      ``HebrewDate`` can be used.
+
+    israel : bool, optional
+      ``True`` if you want the holidays according to the Israel
+      schedule. Defaults to ``False``.
+
+    Returns
+    -------
+    str or ``None``
+      The name of the festival or ``None`` if the given date is not
+      a Jewish festival.
     """
     date = date.to_heb()
     year = date.year
     month = date.month
     day = date.day
-    table = _fast_day_table(year)
-    if date in table:
-        return table[date]
     if month == 7:
         if day in [1, 2]:
             return 'Rosh Hashana'
@@ -101,6 +100,8 @@ def holiday(date, israel=False):
             return 'Shushan Purim'
     elif month == 1 and day in range(15, 22 if israel else 23):
         return 'Pesach'
+    elif month == 2 and day == 14:
+        return 'Pesach Sheni'
     elif month == 2 and day == 18:
         return "Lag Ba'omer"
     elif month == 3 and (day == 6 if israel else day in (6, 7)):
@@ -109,6 +110,35 @@ def holiday(date, israel=False):
         return "Tu B'av"
 
 
+def holiday(date, israel=False):
+    """Return Jewish holiday of given date.
+
+    The holidays include the major and minor religious Jewish
+    holidays including fast days.
+
+    Parameters
+    ----------
+    date : ``HebrewDate``, ``GregorianDate``, or ``JulianDay``
+      Any date that implements a ``to_heb()`` method which returns a
+      ``HebrewDate`` can be used.
+
+    israel : bool, optional
+      ``True`` if you want the holidays according to the israel
+      schedule. Defaults to ``False``.
+
+    Returns
+    -------
+    str or ``None``
+      The name of the holiday or ``None`` if the given date is not
+      a Jewish holiday.
+    """
+    fest = festival(date, israel)
+    if fest:
+        return fest
+    fast = fast_day(date)
+    if fast:
+        return fast
+
 class Year:
     """A Year object represents a Hebrew calendar year.
 
@@ -160,7 +190,10 @@ class Year:
 
     def __add__(self, other):
         """Add int to year."""
-        return Year(self.year + other)
+        try:
+            return Year(self.year + other)
+        except TypeError:
+            raise TypeError('You can only add a number to a year.')
 
     def __sub__(self, other):
         """Subtract int or Year from Year.
@@ -173,7 +206,7 @@ class Year:
         else:
             try:
                 return Year(self.year - other)
-            except AttributeError:
+            except TypeError:
                 raise TypeError('Only an int or another Year object can'
                                 ' be subtracted from a year.')
 
@@ -306,9 +339,12 @@ class Month:
         yearmonths = list(Year(self.year))
         index = yearmonths.index(self.month)
         leftover_months = len(yearmonths[index + 1:])
-        if other <= leftover_months:
-            return Month(self.year, yearmonths[index + other])
-        return Month(self.year + 1, 7).__add__(other - 1 - leftover_months)
+        try:
+            if other <= leftover_months:
+                return Month(self.year, yearmonths[index + other])
+            return Month(self.year + 1, 7).__add__(other - 1 - leftover_months)
+        except (AttributeError, TypeError):
+            raise TypeError('You can only add a number to a year.')
 
 
     def __sub__(self, other):
@@ -327,7 +363,7 @@ class Month:
             return abs(self._elapsed_months() - other._elapsed_months())
         except AttributeError:
             raise TypeError('''You can only subtract a number or a month
-                            object from a month''')
+                            object from a month.''')
 
     def __gt__(self, other):
         if (
@@ -409,7 +445,8 @@ class Month:
         parts = 204 + months*793
         hours = 5 + months*12 + parts//1080
         days = 2 + months*29 + hours//24
-        return {'weekday': days % 7, 'hours': hours % 24, 'parts': parts % 1080}
+        weekday = days % 7 or 7
+        return {'weekday': weekday, 'hours': hours % 24, 'parts': parts % 1080}
 
     def molad_announcement(self):
         """Return the months molad in the announcement form.
