@@ -58,7 +58,7 @@ def _gentable(year, israel=False):
     leap = HebrewDate._is_leap(year)
     pesachday = HebrewDate(year, 1, 15).weekday()
     rosh_hashana = HebrewDate(year, 7, 1)
-    shabbos = (rosh_hashana + 2).shabbos()
+    shabbos = rosh_hashana.shabbos()
     if rosh_hashana.weekday() > 4:
         parshalist.popleft()
 
