@@ -172,6 +172,10 @@ class TestErrors:
                           (2018, 2, 0), (2018, 2, 29), (2012, 2, 30)]:
                           with pytest.raises(ValueError):
                             GregorianDate(*datetuple)
+    
+    def test_JD_errors(self):
+        with pytest.raises(ValueError):
+            JulianDay(-1).to_heb()
 
 class TestReprandStr:
     def test_repr(self, datetypeslist):
@@ -195,6 +199,12 @@ def test_weekday():
     assert HebrewDate(5777, 6, 1).weekday() == 4
     assert JulianDay(2458342.5).weekday() == 1
 
+def test_isoweekday():
+    assert GregorianDate(2020, 9, 20).isoweekday() == 7
+    assert GregorianDate(2020, 10, 3).isoweekday() == 6
+    assert GregorianDate(2020, 10, 5).isoweekday() == 1 
+    assert JulianDay(2458342.5).isoweekday() == 7
+
 class TestMixinMethods:
 
     @pytest.fixture
@@ -221,3 +231,7 @@ def test_from_pydate():
     assert date == GregorianDate.from_pydate(date).to_jd().to_pydate()
     assert date == HebrewDate.from_pydate(date).to_pydate()
     assert date == JulianDay.from_pydate(date).to_pydate()
+
+def test_is_leap():
+    assert GregorianDate(2020, 10, 26).is_leap() == True
+    assert GregorianDate(2021, 10, 26).is_leap() == False
\ No newline at end of file
